@@ -8,7 +8,7 @@ from captur_ml_sdk.dtypes.interfaces.MLGateway.MLTrainRequest import ModelTrainR
 from captur_ml_sdk.dtypes.interfaces.MLGateway.MLEvalRequest import ModelEvaluateRequest
 
 
-class MLGatewayRequest(BaseModel):
+class GatewayRequest(BaseModel):
     meta: Optional[ModelMetaRequest]
     predict: Optional[ModelPredictRequest]
     live_predict: Optional[ModelLivePredictRequest]
