@@ -12,7 +12,7 @@ class LivePredictMeta(BaseModel):
 
 class Model(BaseModel):
     endpoint: str
-    type: str = "classification"
+    type: str
 
     class Config:
         arbitrary_types_allowed = True
