@@ -1,11 +1,13 @@
 from captur_ml_sdk.dtypes.generics import Image
-from captur_ml_sdk.dtypes.exceptions import (
-    ModelNotFoundError,
-    InvalidFilePathError,
-    VersionNotFoundError,
-    ModelHasNoLiveVersionsError,
-)
 from captur_ml_sdk.utils import get_image_components
+from captur_ml_sdk.dtypes.exceptions import InvalidFilePathError
+from captur_ml_sdk.dtypes.interfaces.validators import (
+    check_model_exists,
+    fetch_model_type,
+    ensure_file_exists,
+    check_images_or_imagesfile_is_included,
+    enforce_mutual_exclusivity_between_images_and_imagesfile
+)
 
 from pydantic import (
     BaseModel, validator, root_validator, HttpUrl
@@ -25,7 +27,7 @@ class Data(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    @validator('imagesfile')
+    @ validator('imagesfile')
     def check_imagesfile_has_correct_components(cls, v):
         try:
             get_image_components(v, ".jsonl")
@@ -33,26 +35,28 @@ class Data(BaseModel):
             raise ValueError(str(e))
         return v
 
-    @root_validator
-    def enforce_mutual_exclusivity_between_images_and_imagesfile(cls, values):
-        images = values.get("images")
-        imagesfile = values.get("imagesfile")
+    _ensure_file_exists_imagesfile = validator(
+        'imagesfile', allow_reuse=True)(ensure_file_exists)
+    _ensure_file_exists_labelsfile = validator(
+        'labelsfile', allow_reuse=True)(ensure_file_exists)
 
-        if images and imagesfile:
-            raise ValueError(
-                "Only one of predict:data.images or predict:data.imagesfile"
-                "can be used"
-            )
-        return values
+    _images_or_imagesfile_ = root_validator(
+        check_images_or_imagesfile_is_included, allow_reuse=True)
+    _mutual_exclusivity = root_validator(
+        enforce_mutual_exclusivity_between_images_and_imagesfile, allow_reuse=True)
 
 
 class Model(BaseModel):
     name: str
     version: Optional[str] = "HEAD"
+    type: Optional[str]
 
     class Config:
         arbitrary_types_allowed = True
 
+    _model_exists = root_validator(check_model_exists, allow_reuse=True)
+    _get_model_type = root_validator(fetch_model_type, allow_reuse=True)
+
 
 class ModelPredictRequest(BaseModel):
     meta: Optional[PredictMeta] = None
